@@ -26,8 +26,9 @@ def stitch_tiles(blend=True, sigma=5):
     @partial(transform, output_type='stitched_image')
     def func_stitch(tiles):
 
-        profile = tiles.profile
-        nonempty_indices = profile.nonempty_indices
+        tiles = tiles.compute()
+
+        nonempty_indices = tiles.nonempty_indices
         first_tile = tiles[nonempty_indices[0]]
         tile_size = first_tile.shape[-2:]
         dtype = first_tile.dtype
@@ -40,7 +41,7 @@ def stitch_tiles(blend=True, sigma=5):
         if blend:
 
             avg = np.zeros(stitch_shape[-2:])
-            taper = _generate_taper(tile_size, profile.overlap, sigma)
+            taper = _generate_taper(tile_size, tiles.profile.overlap, sigma)
 
             for index in nonempty_indices:
 
@@ -54,7 +55,7 @@ def stitch_tiles(blend=True, sigma=5):
                 stitched[stitch_slice] = stitched[stitch_slice] + tile[tile_slice] * taper[tile_slice]
                 avg[stitch_slice[1:]] = avg[stitch_slice[1:]] + taper[tile_slice]
 
-            stitched = stitched / avg
+            stitched = stitched / (avg + 1e-7)
             stitched = stitched.astype(dtype)
 
         else:
@@ -92,12 +93,11 @@ def stitch_masks(iou_threshold=0.1):
     @partial(transform, output_type='stitched_image')
     def func_stitch(tiles):
 
-        masks = tiles
+        masks = tiles.compute()
 
         masks = utils.unpad_tiles(masks)
 
-        profile = masks.profile
-        nonempty_indices = profile.nonempty_indices
+        nonempty_indices = masks.nonempty_indices
         first_mask = masks[nonempty_indices[0]]
 
         image_shape = masks.image_shape
@@ -142,11 +142,12 @@ def stitch_masks(iou_threshold=0.1):
                 mask = mask.reshape(-1, *mask.shape[-2:])
                 mask = mask[z]
                 regions = measure.regionprops(mask)
+                regions = {region.label: region for region in regions}
 
                 for blob in blobs:
 
-                    mask_crop = regions[blob - 1].image
-                    s = regions[blob - 1].slice
+                    mask_crop = regions[blob].image
+                    s = regions[blob].slice
                     s_image = (slice(s[0].start + tile_index[0, 0],
                                      s[0].stop + tile_index[0, 0]),
                                slice(s[1].start + tile_index[1, 0],
@@ -179,10 +180,9 @@ def stitch_coords():
     @partial(transform, input_type='tiled_coords', output_type='stitched_coords')
     def func_stitch(tiles):
 
-        coords = tiles
+        coords = tiles.compute()
 
-        profile = coords.profile
-        nonempty_indices = profile.nonempty_indices
+        nonempty_indices = coords.nonempty_indices
         tile_indices_iterator = coords.tile_indices_iterator
         border_indices_iterator = coords.border_indices_iterator
         first_coord = coords[nonempty_indices[0]]
